@@ -2,7 +2,7 @@
 
 package HPC::Runner::GnuParallel;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use DateTime;
 use DateTime::Format::Duration;
@@ -11,7 +11,7 @@ use Moose;
 extends 'HPC::Runner';
 extends 'HPC::Runner::MCE';
 
-with 'MooseX::Getopt';
+#with 'MooseX::Getopt';
 with 'MooseX::Getopt::Usage';
 with 'MooseX::Getopt::Usage::Role::Man';
 
@@ -36,7 +36,7 @@ HPC::Runner::GnuParallel - Run arbitrary bash commands using GNU parallel. Can b
 
 Run straight as :
 
-  cat stuff.cmd | parallelparser.pl | parallel --joblog `pwd`/runtasks.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir `pwd`/gnulogs/
+  cat stuff.cmd | parallelparser.pl | parallel --joblog `pwd`/runtasks.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir `pwd`/gnulogs/ --seq {#}
 
   Where stuff.cmd is a file with the commands you need run.
 
@@ -79,9 +79,14 @@ has 'command' => (
 );
 
 
+has 'seq' => (
+    is => 'rw',
+    isa => 'Int'
+);
+
 =head2 go
 
-Initialize MCE things and use Runner::Init to parse and exec commands
+Initialize MCE things and use HPC::Runner to parse and exec commands
 
 =cut
 
@@ -122,10 +127,9 @@ sub parse_file_gnuparallel{
 
     $DB::single=2;
 
-#    $self->log->info("Enqueuing command:\n".$self->cmd);
+    $self->counter($self->seq);
     $self->run_command_mce;
     $self->clear_cmd;
-    $self->inc_counter;
 }
 
 
@@ -136,11 +140,19 @@ __END__
 
 =head1 Acknowledgements
 
+Before version 0.05
+
 This module was originally developed at and for Weill Cornell Medical
 College in Qatar within ITS Advanced Computing Team. With approval from
 WCMC-Q, this information was generalized and put on github, for which
 the authors would like to express their gratitude.
 
+As of version 0.05:
+
+This modules continuing development is supported by NYU Abu Dhabi in the Center for Genomics and Systems Biology.
+With approval from NYUAD, this information was generalized and put on bitbucket, for which
+the authors would like to express their gratitude.
+
 =head1 AUTHOR
 
 Jillian Rowe E<lt>jillian.e.rowe@gmail.comE<gt>
