@@ -1,16 +1,17 @@
-#!/usr/bin/env perl 
+#!/usr/bin/env perl
 #===============================================================================
 #
 #         FILE:  mcerunner.pl
 #
-#        USAGE:  ./mcerunner.pl  
+#        USAGE:  ./mcerunner.pl
 #
-#  DESCRIPTION: Run jobs use MCE 
+#  DESCRIPTION: Run jobs use MCE
 #===============================================================================
 
 #package Main;
 
 my $cmd = "";
+my $x = 1;
 
 foreach $line ( <STDIN> ) {
     chomp( $line );
@@ -26,7 +27,9 @@ foreach $line ( <STDIN> ) {
         }
         else{
             $cmd .= $line;
+            system("export SEQNUM=$x");
             print "$cmd\n";
+            $x++;
             $cmd = "";
         }
     }
@@ -38,7 +41,9 @@ foreach $line ( <STDIN> ) {
         }
         else{
             $cmd = $line;
+            system("export SEQNUM=$x");
             print "$cmd\n";
+            $x++;
             $cmd = "";
         }
     }
